@@ -1,33 +1,38 @@
-import math
+from dataclasses import dataclass
 from datetime import datetime, timedelta
 from decimal import Decimal
 from typing import Callable, Optional, Tuple
 
-from fast_stark_crypto import get_order_msg_hash
-
 from x10.perpetual.accounts import StarkPerpetualAccount
-from x10.perpetual.amounts import (
-    ROUNDING_BUY_CONTEXT,
-    ROUNDING_FEE_CONTEXT,
-    ROUNDING_SELL_CONTEXT,
-    HumanReadableAmount,
-    StarkAmount,
-)
 from x10.perpetual.configuration import StarknetDomain
 from x10.perpetual.fees import DEFAULT_FEES, TradingFeeModel
 from x10.perpetual.markets import MarketModel
+from x10.perpetual.order_object_settlement import (
+    OrderSettlementData,
+    SettlementDataCtx,
+    create_order_settlement_data,
+)
 from x10.perpetual.orders import (
+    CreateOrderTpslTriggerModel,
+    NewOrderModel,
+    OrderPriceType,
     OrderSide,
+    OrderTpslType,
+    OrderTriggerPriceType,
     OrderType,
-    PerpetualOrderModel,
     SelfTradeProtectionLevel,
-    SettlementSignatureModel,
-    StarkDebuggingOrderAmountsModel,
-    StarkSettlementModel,
     TimeInForce,
 )
-from x10.utils import generate_nonce
 from x10.utils.date import to_epoch_millis, utc_now
+from x10.utils.nonce import generate_nonce
+
+
+@dataclass(kw_only=True)
+class OrderTpslTriggerParam:
+    trigger_price: Decimal
+    trigger_price_type: OrderTriggerPriceType
+    price: Decimal
+    price_type: OrderPriceType
 
 
 def create_order_object(
@@ -47,7 +52,10 @@ def create_order_object(
     builder_fee: Optional[Decimal] = None,
     builder_id: Optional[int] = None,
     reduce_only: bool = False,
-) -> PerpetualOrderModel:
+    tp_sl_type: Optional[OrderTpslType] = None,
+    take_profit: Optional[OrderTpslTriggerParam] = None,
+    stop_loss: Optional[OrderTpslTriggerParam] = None,
+) -> NewOrderModel:
     """
     Creates an order object to be placed on the exchange using the `place_order` method.
     """
@@ -78,10 +86,29 @@ def create_order_object(
         builder_fee=builder_fee,
         builder_id=builder_id,
         reduce_only=reduce_only,
+        tp_sl_type=tp_sl_type,
+        take_profit=take_profit,
+        stop_loss=stop_loss,
     )
 
 
+def __create_order_tpsl_trigger_model(trigger_param: OrderTpslTriggerParam, settlement_data: OrderSettlementData):
+    return CreateOrderTpslTriggerModel(
+        trigger_price=trigger_param.trigger_price,
+        trigger_price_type=trigger_param.trigger_price_type,
+        price=trigger_param.price,
+        price_type=trigger_param.price_type,
+        settlement=settlement_data.settlement,
+        debugging_amounts=settlement_data.debugging_amounts,
+    )
+
+
+def __get_opposite_side(side: OrderSide) -> OrderSide:
+    return OrderSide.BUY if side == OrderSide.SELL else OrderSide.SELL
+
+
 def __create_order_object(
+    *,
     market: MarketModel,
     synthetic_amount: Decimal,
     price: Decimal,
@@ -102,66 +129,83 @@ def __create_order_object(
     builder_fee: Optional[Decimal] = None,
     builder_id: Optional[int] = None,
     reduce_only: bool = False,
-) -> PerpetualOrderModel:
-    if exact_only:
-        raise NotImplementedError("`exact_only` option is not supported yet")
+    tp_sl_type: Optional[OrderTpslType] = None,
+    take_profit: Optional[OrderTpslTriggerParam] = None,
+    stop_loss: Optional[OrderTpslTriggerParam] = None,
+) -> NewOrderModel:
+    if side not in OrderSide:
+        raise ValueError(f"Unexpected order side value: {side}")
+
+    if time_in_force not in TimeInForce or time_in_force == TimeInForce.FOK:
+        raise ValueError(f"Unexpected time in force value: {time_in_force}")
 
     if expire_time is None:
         raise ValueError("`expire_time` must be provided")
+
+    if exact_only:
+        raise NotImplementedError("`exact_only` option is not supported yet")
+
+    if tp_sl_type == OrderTpslType.POSITION:
+        raise NotImplementedError("`POSITION` TPSL type is not supported yet")
+
+    if (take_profit and take_profit.price_type == OrderPriceType.MARKET) or (
+        stop_loss and stop_loss.price_type == OrderPriceType.MARKET
+    ):
+        raise NotImplementedError("TPSL `MARKET` price type is not supported yet")
+
     if nonce is None:
         nonce = generate_nonce()
-    is_buying_synthetic = side == OrderSide.BUY
-    rounding_context = ROUNDING_BUY_CONTEXT if is_buying_synthetic else ROUNDING_SELL_CONTEXT
 
-    collateral_amount_human = HumanReadableAmount(synthetic_amount * price, market.collateral_asset)
-    synthetic_amount_human = HumanReadableAmount(synthetic_amount, market.synthetic_asset)
-    total_fee = fees.taker_fee_rate + (builder_fee if builder_fee is not None else 0)
-    fee_amount_human = HumanReadableAmount(
-        total_fee * collateral_amount_human.value,
-        market.collateral_asset,
-    )
     fee_rate = fees.taker_fee_rate
 
-    stark_collateral_amount: StarkAmount = collateral_amount_human.to_stark_amount(rounding_context=rounding_context)
-    stark_synthetic_amount: StarkAmount = synthetic_amount_human.to_stark_amount(rounding_context=rounding_context)
-    stark_fee_amount: StarkAmount = fee_amount_human.to_stark_amount(rounding_context=ROUNDING_FEE_CONTEXT)
-
-    if is_buying_synthetic:
-        stark_collateral_amount = stark_collateral_amount.negate()
-    else:
-        stark_synthetic_amount = stark_synthetic_amount.negate()
-
-    debugging_amounts = StarkDebuggingOrderAmountsModel(
-        collateral_amount=Decimal(stark_collateral_amount.value),
-        fee_amount=Decimal(stark_fee_amount.value),
-        synthetic_amount=Decimal(stark_synthetic_amount.value),
-    )
-
-    order_hash = hash_order(
-        amount_synthetic=stark_synthetic_amount,
-        amount_collateral=stark_collateral_amount,
-        max_fee=stark_fee_amount,
+    settlement_data_ctx = SettlementDataCtx(
+        market=market,
+        fees=fees,
+        builder_fee=builder_fee,
         nonce=nonce,
-        position_id=collateral_position_id,
-        expiration_timestamp=expire_time,
+        collateral_position_id=collateral_position_id,
+        expire_time=expire_time,
+        signer=signer,
         public_key=public_key,
         starknet_domain=starknet_domain,
     )
-
-    (order_signature_r, order_signature_s) = signer(order_hash)
-    settlement = StarkSettlementModel(
-        signature=SettlementSignatureModel(r=order_signature_r, s=order_signature_s),
-        stark_key=public_key,
-        collateral_position=Decimal(collateral_position_id),
+    settlement_data = create_order_settlement_data(
+        side=side, synthetic_amount=synthetic_amount, price=price, ctx=settlement_data_ctx
+    )
+    tp_trigger_model = (
+        __create_order_tpsl_trigger_model(
+            take_profit,
+            create_order_settlement_data(
+                side=__get_opposite_side(side),
+                synthetic_amount=synthetic_amount,
+                price=take_profit.price,
+                ctx=settlement_data_ctx,
+            ),
+        )
+        if take_profit
+        else None
+    )
+    sl_trigger_model = (
+        __create_order_tpsl_trigger_model(
+            stop_loss,
+            create_order_settlement_data(
+                side=__get_opposite_side(side),
+                synthetic_amount=synthetic_amount,
+                price=stop_loss.price,
+                ctx=settlement_data_ctx,
+            ),
+        )
+        if stop_loss
+        else None
     )
 
-    order_id = str(order_hash) if order_external_id is None else order_external_id
-    order = PerpetualOrderModel(
+    order_id = str(settlement_data.order_hash) if order_external_id is None else order_external_id
+    order = NewOrderModel(
         id=order_id,
         market=market.name,
         type=OrderType.LIMIT,
         side=side,
-        qty=synthetic_amount_human.value,
+        qty=settlement_data.synthetic_amount_human.value,
         price=price,
         post_only=post_only,
         time_in_force=time_in_force,
@@ -170,45 +214,14 @@ def __create_order_object(
         self_trade_protection_level=self_trade_protection_level,
         nonce=Decimal(nonce),
         cancel_id=previous_order_external_id,
-        settlement=settlement,
-        debugging_amounts=debugging_amounts,
+        settlement=settlement_data.settlement,
+        tp_sl_type=tp_sl_type,
+        take_profit=tp_trigger_model,
+        stop_loss=sl_trigger_model,
+        debugging_amounts=settlement_data.debugging_amounts,
         builderFee=builder_fee,
         builderId=builder_id,
         reduce_only=reduce_only,
     )
 
     return order
-
-
-def hash_order(
-    amount_synthetic: StarkAmount,
-    amount_collateral: StarkAmount,
-    max_fee: StarkAmount,
-    nonce: int,
-    position_id: int,
-    expiration_timestamp: datetime,
-    public_key: int,
-    starknet_domain: StarknetDomain,
-) -> int:
-    synthetic_asset = amount_synthetic.asset
-    collateral_asset = amount_collateral.asset
-
-    expire_time_with_buffer = expiration_timestamp + timedelta(days=14)
-    expire_time_as_seconds = math.ceil(expire_time_with_buffer.timestamp())
-
-    return get_order_msg_hash(
-        position_id=position_id,
-        base_asset_id=int(synthetic_asset.settlement_external_id, 16),
-        base_amount=amount_synthetic.value,
-        quote_asset_id=int(collateral_asset.settlement_external_id, 16),
-        quote_amount=amount_collateral.value,
-        fee_amount=max_fee.value,
-        fee_asset_id=int(collateral_asset.settlement_external_id, 16),
-        expiration=expire_time_as_seconds,
-        salt=nonce,
-        user_public_key=public_key,
-        domain_name=starknet_domain.name,
-        domain_version=starknet_domain.version,
-        domain_chain_id=starknet_domain.chain_id,
-        domain_revision=starknet_domain.revision,
-    )
